==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/inputs/MabProtectionPolicyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.inputs

import com.pulumi.azurenative.recoveryservices.inputs.MabProtectionPolicyArgs.builder
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Any
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Mab container-specific backup policy.
 * @property backupManagementType This property will be used as the discriminator for deciding the specific types in the polymorphic chain of types.
 * Expected value is 'MAB'.
 * @property protectedItemsCount Number of items associated with this policy.
 * @property resourceGuardOperationRequests ResourceGuard Operation Requests
 * @property retentionPolicy Retention policy details.
 * @property schedulePolicy Backup schedule of backup policy.
 */
public data class MabProtectionPolicyArgs(
    public val backupManagementType: Output<String>,
    public val protectedItemsCount: Output<Int>? = null,
    public val resourceGuardOperationRequests: Output<List<String>>? = null,
    public val retentionPolicy:
    Output<Either<LongTermRetentionPolicyArgs, SimpleRetentionPolicyArgs>>? = null,
    public val schedulePolicy: Output<Any>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.recoveryservices.inputs.MabProtectionPolicyArgs> {
    override fun toJava(): com.pulumi.azurenative.recoveryservices.inputs.MabProtectionPolicyArgs =
        com.pulumi.azurenative.recoveryservices.inputs.MabProtectionPolicyArgs.builder()
            .backupManagementType(backupManagementType.applyValue({ args0 -> args0 }))
            .protectedItemsCount(protectedItemsCount?.applyValue({ args0 -> args0 }))
            .resourceGuardOperationRequests(
                resourceGuardOperationRequests?.applyValue({ args0 ->
                    args0.map({ args0 -> args0 })
                }),
            )
            .retentionPolicy(
                retentionPolicy?.applyValue({ args0 ->
                    args0.transform({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            )
            .schedulePolicy(schedulePolicy?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [MabProtectionPolicyArgs].
 */
@PulumiTagMarker
public class MabProtectionPolicyArgsBuilder internal constructor() {
    private var backupManagementType: Output<String>? = null

    private var protectedItemsCount: Output<Int>? = null

    private var resourceGuardOperationRequests: Output<List<String>>? = null

    private var retentionPolicy:
        Output<Either<LongTermRetentionPolicyArgs, SimpleRetentionPolicyArgs>>? = null

    private var schedulePolicy: Output<Any>? = null

    /**
     * @param value This property will be used as the discriminator for deciding the specific types in the polymorphic chain of types.
     * Expected value is 'MAB'.
     */
    @JvmName("hdarmeyqwtafhlqh")
    public suspend fun backupManagementType(`value`: Output<String>) {
        this.backupManagementType = value
    }

    /**
     * @param value Number of items associated with this policy.
     */
    @JvmName("csmkwgtxcxesrrgd")
    public suspend fun protectedItemsCount(`value`: Output<Int>) {
        this.protectedItemsCount = value
    }

    /**
     * @param value ResourceGuard Operation Requests
     */
    @JvmName("hwetfnvdeptjxcrf")
    public suspend fun resourceGuardOperationRequests(`value`: Output<List<String>>) {
        this.resourceGuardOperationRequests = value
    }

    @JvmName("ulqajxpflvjvxitr")
    public suspend fun resourceGuardOperationRequests(vararg values: Output<String>) {
        this.resourceGuardOperationRequests = Output.all(values.asList())
    }

    /**
     * @param values ResourceGuard Operation Requests
     */
    @JvmName("keknnoqybdxauavk")
    public suspend fun resourceGuardOperationRequests(values: List<Output<String>>) {
        this.resourceGuardOperationRequests = Output.all(values)
    }

    /**
     * @param value Retention policy details.
     */
    @JvmName("hpidgtjvhlyxwkyj")
    public suspend
    fun retentionPolicy(`value`: Output<Either<LongTermRetentionPolicyArgs, SimpleRetentionPolicyArgs>>) {
        this.retentionPolicy = value
    }

    /**
     * @param value Backup schedule of backup policy.
     */
    @JvmName("upubhfofjbdlcckm")
    public suspend fun schedulePolicy(`value`: Output<Any>) {
        this.schedulePolicy = value
    }

    /**
     * @param value This property will be used as the discriminator for deciding the specific types in the polymorphic chain of types.
     * Expected value is 'MAB'.
     */
    @JvmName("nljedebfkebafsjo")
    public suspend fun backupManagementType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.backupManagementType = mapped
    }

    /**
     * @param value Number of items associated with this policy.
     */
    @JvmName("uabagoetnwcxgkgb")
    public suspend fun protectedItemsCount(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.protectedItemsCount = mapped
    }

    /**
     * @param value ResourceGuard Operation Requests
     */
    @JvmName("xorwiibtyktugbnx")
    public suspend fun resourceGuardOperationRequests(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGuardOperationRequests = mapped
    }

    /**
     * @param values ResourceGuard Operation Requests
     */
    @JvmName("txjpscgikbkwytbt")
    public suspend fun resourceGuardOperationRequests(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.resourceGuardOperationRequests = mapped
    }

    /**
     * @param value Retention policy details.
     */
    @JvmName("mvngnrcrjkxpreyo")
    public suspend
    fun retentionPolicy(`value`: Either<LongTermRetentionPolicyArgs, SimpleRetentionPolicyArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.retentionPolicy = mapped
    }

    /**
     * @param value Retention policy details.
     */
    @JvmName("gjglkkptkeejjvre")
    public fun retentionPolicy(`value`: LongTermRetentionPolicyArgs) {
        val toBeMapped = Either.ofLeft<LongTermRetentionPolicyArgs, SimpleRetentionPolicyArgs>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.retentionPolicy = mapped
    }

    /**
     * @param value Retention policy details.
     */
    @JvmName("ppnaivabtmmxeiau")
    public fun retentionPolicy(`value`: SimpleRetentionPolicyArgs) {
        val toBeMapped = Either.ofRight<LongTermRetentionPolicyArgs, SimpleRetentionPolicyArgs>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.retentionPolicy = mapped
    }

    /**
     * @param value Backup schedule of backup policy.
     */
    @JvmName("lctejslfadxiwiie")
    public suspend fun schedulePolicy(`value`: Any?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.schedulePolicy = mapped
    }

    internal fun build(): MabProtectionPolicyArgs = MabProtectionPolicyArgs(
        backupManagementType = backupManagementType ?: throw
            PulumiNullFieldException("backupManagementType"),
        protectedItemsCount = protectedItemsCount,
        resourceGuardOperationRequests = resourceGuardOperationRequests,
        retentionPolicy = retentionPolicy,
        schedulePolicy = schedulePolicy,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/inputs/MabProtectionPolicyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.inputs

import com.pulumi.azurenative.recoveryservices.inputs.MabProtectionPolicyArgs.builder
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Any
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Mab container-specific backup policy.
 * @property backupManagementType This property will be used as the discriminator for deciding the specific types in the polymorphic chain of types.
 * Expected value is 'MAB'.
 * @property protectedItemsCount Number of items associated with this policy.
 * @property resourceGuardOperationRequests ResourceGuard Operation Requests
 * @property retentionPolicy Retention policy details.
 * @property schedulePolicy Backup schedule of backup policy.
 */
public data class MabProtectionPolicyArgs(
    public val backupManagementType: Output<String>,
    public val protectedItemsCount: Output<Int>? = null,
    public val resourceGuardOperationRequests: Output<List<String>>? = null,
    public val retentionPolicy:
    Output<Either<LongTermRetentionPolicyArgs, SimpleRetentionPolicyArgs>>? = null,
    public val schedulePolicy: Output<Any>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.recoveryservices.inputs.MabProtectionPolicyArgs> {
    override fun toJava(): com.pulumi.azurenative.recoveryservices.inputs.MabProtectionPolicyArgs =
        com.pulumi.azurenative.recoveryservices.inputs.MabProtectionPolicyArgs.builder()
            .backupManagementType(backupManagementType.applyValue({ args0 -> args0 }))
            .protectedItemsCount(protectedItemsCount?.applyValue({ args0 -> args0 }))
            .resourceGuardOperationRequests(
                resourceGuardOperationRequests?.applyValue({ args0 ->
                    args0.map({ args0 -> args0 })
                }),
            )
            .retentionPolicy(
                retentionPolicy?.applyValue({ args0 ->
                    args0.transform({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            )
            .schedulePolicy(schedulePolicy?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [MabProtectionPolicyArgs].
 */
@PulumiTagMarker
public class MabProtectionPolicyArgsBuilder internal constructor() {
    private var backupManagementType: Output<String>? = null

    private var protectedItemsCount: Output<Int>? = null

    private var resourceGuardOperationRequests: Output<List<String>>? = null

    private var retentionPolicy:
        Output<Either<LongTermRetentionPolicyArgs, SimpleRetentionPolicyArgs>>? = null

    private var schedulePolicy: Output<Any>? = null

    /**
     * @param value This property will be used as the discriminator for deciding the specific types in the polymorphic chain of types.
     * Expected value is 'MAB'.
     */
    @JvmName("jdrdcggtytpdcacg")
    public suspend fun backupManagementType(`value`: Output<String>) {
        this.backupManagementType = value
    }

    /**
     * @param value Number of items associated with this policy.
     */
    @JvmName("xggnarowidigjdix")
    public suspend fun protectedItemsCount(`value`: Output<Int>) {
        this.protectedItemsCount = value
    }

    /**
     * @param value ResourceGuard Operation Requests
     */
    @JvmName("dbauwhqvuoidnbxy")
    public suspend fun resourceGuardOperationRequests(`value`: Output<List<String>>) {
        this.resourceGuardOperationRequests = value
    }

    @JvmName("oonvkhhstvhvlamj")
    public suspend fun resourceGuardOperationRequests(vararg values: Output<String>) {
        this.resourceGuardOperationRequests = Output.all(values.asList())
    }

    /**
     * @param values ResourceGuard Operation Requests
     */
    @JvmName("obwferrtsopxqhnf")
    public suspend fun resourceGuardOperationRequests(values: List<Output<String>>) {
        this.resourceGuardOperationRequests = Output.all(values)
    }

    /**
     * @param value Retention policy details.
     */
    @JvmName("mgauahaqoxqkbnlg")
    public suspend
    fun retentionPolicy(`value`: Output<Either<LongTermRetentionPolicyArgs, SimpleRetentionPolicyArgs>>) {
        this.retentionPolicy = value
    }

    /**
     * @param value Backup schedule of backup policy.
     */
    @JvmName("mynmhwbjqccgllgh")
    public suspend fun schedulePolicy(`value`: Output<Any>) {
        this.schedulePolicy = value
    }

    /**
     * @param value This property will be used as the discriminator for deciding the specific types in the polymorphic chain of types.
     * Expected value is 'MAB'.
     */
    @JvmName("tllqclwksgvnatjf")
    public suspend fun backupManagementType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.backupManagementType = mapped
    }

    /**
     * @param value Number of items associated with this policy.
     */
    @JvmName("lnrtdtrtcpsarrsx")
    public suspend fun protectedItemsCount(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.protectedItemsCount = mapped
    }

    /**
     * @param value ResourceGuard Operation Requests
     */
    @JvmName("tqoujltsbvtcaicq")
    public suspend fun resourceGuardOperationRequests(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGuardOperationRequests = mapped
    }

    /**
     * @param values ResourceGuard Operation Requests
     */
    @JvmName("egsrqlrdoxrulxqw")
    public suspend fun resourceGuardOperationRequests(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.resourceGuardOperationRequests = mapped
    }

    /**
     * @param value Retention policy details.
     */
    @JvmName("mubumkacuqlxjvoy")
    public suspend
    fun retentionPolicy(`value`: Either<LongTermRetentionPolicyArgs, SimpleRetentionPolicyArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.retentionPolicy = mapped
    }

    /**
     * @param value Retention policy details.
     */
    @JvmName("ptyvjeikkvahnqik")
    public fun retentionPolicy(`value`: LongTermRetentionPolicyArgs) {
        val toBeMapped = Either.ofLeft<LongTermRetentionPolicyArgs, SimpleRetentionPolicyArgs>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.retentionPolicy = mapped
    }

    /**
     * @param value Retention policy details.
     */
    @JvmName("frkkflwoxlliihlg")
    public fun retentionPolicy(`value`: SimpleRetentionPolicyArgs) {
        val toBeMapped = Either.ofRight<LongTermRetentionPolicyArgs, SimpleRetentionPolicyArgs>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.retentionPolicy = mapped
    }

    /**
     * @param value Backup schedule of backup policy.
     */
    @JvmName("gprkfjhjsggpgcmb")
    public suspend fun schedulePolicy(`value`: Any?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.schedulePolicy = mapped
    }

    internal fun build(): MabProtectionPolicyArgs = MabProtectionPolicyArgs(
        backupManagementType = backupManagementType ?: throw
            PulumiNullFieldException("backupManagementType"),
        protectedItemsCount = protectedItemsCount,
        resourceGuardOperationRequests = resourceGuardOperationRequests,
        retentionPolicy = retentionPolicy,
        schedulePolicy = schedulePolicy,
    )
}
